@@ -77,7 +77,7 @@ def init(name: str, api_type: str, fauna_key: str, bucket: str, email: str, stag
             key = client.query(
                 q.create_key({'database': q.database(db_name), 'role': 'admin'})
             )
-            click.echo(key)
+            click.secho(f'Fauna Local Secret (copy into your .env or pipenv file): {key}', fg='green')
 
     else:
         click.echo('There is already a project file in this directory.')
@@ -136,10 +136,11 @@ def local(hostname: str, port: int, wsgi: str, config_file: str, use_debugger: b
 
 
 @pfunk.command()
+@click.option('--publish_locally', prompt=True, help='Specifies whether to publish the schema locally.', default=False)
 @click.option('--config_path', help='Configuration file path', default='pfunk.json')
 @click.option('--project_path', help='Project module path')
 @click.argument('stage_name')
-def publish(stage_name: str, project_path: str, config_path: str):
+def publish(stage_name: str, project_path: str, config_path: str, publish_locally: bool):
     """
     Publish GraphQL schema to Fauna
     Args:
@@ -150,13 +151,14 @@ def publish(stage_name: str, project_path: str, config_path: str):
     Returns:
 
     """
-    config = load_config_file(config_path)
-    sys.path.insert(0, os.getcwd())
-    if not project_path:
-        project_path = f'{config.get("name")}.project.project'
-    project = import_util(project_path)
-    secret = config['stages'][stage_name]['fauna_secret']
-    os.environ['FAUNA_SECRET'] = secret
+    if not publish_locally:
+        config = load_config_file(config_path)
+        sys.path.insert(0, os.getcwd())
+        if not project_path:
+            project_path = f'{config.get("name")}.project.project'
+        project = import_util(project_path)
+        secret = config['stages'][stage_name]['fauna_secret']
+        os.environ['FAUNA_SECRET'] = secret
     project.publish()
 
 
